pub struct DeleteResourcePermissionStatementFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteResourcePermissionStatement.
Remove a permission statement from the account’s SignIn resource-based policy
Implementations
Sourceimpl DeleteResourcePermissionStatementFluentBuilder
impl DeleteResourcePermissionStatementFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteResourcePermissionStatementInputBuilder
pub fn as_input(&self) -> &DeleteResourcePermissionStatementInputBuilder
Access the DeleteResourcePermissionStatement as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteResourcePermissionStatementOutput, SdkError<DeleteResourcePermissionStatementError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteResourcePermissionStatementOutput, SdkError<DeleteResourcePermissionStatementError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteResourcePermissionStatementOutput, DeleteResourcePermissionStatementError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteResourcePermissionStatementOutput, DeleteResourcePermissionStatementError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn statement_id(self, input: impl Into<String>) -> Self
pub fn statement_id(self, input: impl Into<String>) -> Self
Unique identifier of the permission statement to delete
Sourcepub fn set_statement_id(self, input: Option<String>) -> Self
pub fn set_statement_id(self, input: Option<String>) -> Self
Unique identifier of the permission statement to delete
Sourcepub fn get_statement_id(&self) -> &Option<String>
pub fn get_statement_id(&self) -> &Option<String>
Unique identifier of the permission statement to delete
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Idempotency token for the request
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Idempotency token for the request
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Idempotency token for the request