pub struct ListResourcePermissionStatementsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListResourcePermissionStatements.
Retrieve all permission statements in the account’s SignIn resource-based policy
Implementations
Sourceimpl ListResourcePermissionStatementsFluentBuilder
impl ListResourcePermissionStatementsFluentBuilder
Sourcepub fn as_input(&self) -> &ListResourcePermissionStatementsInputBuilder
pub fn as_input(&self) -> &ListResourcePermissionStatementsInputBuilder
Access the ListResourcePermissionStatements as a reference.
Sourcepub async fn send(
self,
) -> Result<ListResourcePermissionStatementsOutput, SdkError<ListResourcePermissionStatementsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListResourcePermissionStatementsOutput, SdkError<ListResourcePermissionStatementsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListResourcePermissionStatementsOutput, ListResourcePermissionStatementsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListResourcePermissionStatementsOutput, ListResourcePermissionStatementsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListResourcePermissionStatementsPaginator
pub fn into_paginator(self) -> ListResourcePermissionStatementsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Maximum number of results to return
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Maximum number of results to return
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Maximum number of results to return
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Token for pagination
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Token for pagination
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Token for pagination