pub struct PutConsoleAuthorizationConfigurationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PutConsoleAuthorizationConfiguration.
Enable console authorization configuration with automatic scope detection
Implementations
Sourceimpl PutConsoleAuthorizationConfigurationFluentBuilder
impl PutConsoleAuthorizationConfigurationFluentBuilder
Sourcepub fn as_input(&self) -> &PutConsoleAuthorizationConfigurationInputBuilder
pub fn as_input(&self) -> &PutConsoleAuthorizationConfigurationInputBuilder
Access the PutConsoleAuthorizationConfiguration as a reference.
Sourcepub async fn send(
self,
) -> Result<PutConsoleAuthorizationConfigurationOutput, SdkError<PutConsoleAuthorizationConfigurationError, HttpResponse>>
pub async fn send( self, ) -> Result<PutConsoleAuthorizationConfigurationOutput, SdkError<PutConsoleAuthorizationConfigurationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<PutConsoleAuthorizationConfigurationOutput, PutConsoleAuthorizationConfigurationError, Self>
pub fn customize( self, ) -> CustomizableOperation<PutConsoleAuthorizationConfigurationOutput, PutConsoleAuthorizationConfigurationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn set_target_id(self, input: Option<String>) -> Self
pub fn set_target_id(self, input: Option<String>) -> Self
Target account identifier
Sourcepub fn get_target_id(&self) -> &Option<String>
pub fn get_target_id(&self) -> &Option<String>
Target account identifier