#[non_exhaustive]pub struct PutConsoleAuthorizationConfigurationOutputBuilder { /* private fields */ }Expand description
A builder for PutConsoleAuthorizationConfigurationOutput.
Implementations
Sourceimpl PutConsoleAuthorizationConfigurationOutputBuilder
impl PutConsoleAuthorizationConfigurationOutputBuilder
Sourcepub fn target_id(self, input: impl Into<String>) -> Self
pub fn target_id(self, input: impl Into<String>) -> Self
Target account identifier This field is required.
Sourcepub fn set_target_id(self, input: Option<String>) -> Self
pub fn set_target_id(self, input: Option<String>) -> Self
Target account identifier
Sourcepub fn get_target_id(&self) -> &Option<String>
pub fn get_target_id(&self) -> &Option<String>
Target account identifier
Sourcepub fn scope(self, input: impl Into<String>) -> Self
pub fn scope(self, input: impl Into<String>) -> Self
Authorization scope This field is required.
Whether console authorization is enabled This field is required.
Whether console authorization is enabled
Whether console authorization is enabled
Sourcepub fn build(
self,
) -> Result<PutConsoleAuthorizationConfigurationOutput, BuildError>
pub fn build( self, ) -> Result<PutConsoleAuthorizationConfigurationOutput, BuildError>
Consumes the builder and constructs a PutConsoleAuthorizationConfigurationOutput.
This method will fail if any of the following fields are not set: