PutResourcePermissionStatementFluentBuilder

Struct PutResourcePermissionStatementFluentBuilder 

pub struct PutResourcePermissionStatementFluentBuilder { /* private fields */ }
Fluent builder constructing a request to PutResourcePermissionStatement.

Create a permission statement in the account’s SignIn resource-based policy

Implementations

Source

impl PutResourcePermissionStatementFluentBuilder

pub fn as_input(&self) -> &PutResourcePermissionStatementInputBuilder

Access the PutResourcePermissionStatement as a reference.

pub async fn send( self, ) -> Result<PutResourcePermissionStatementOutput, SdkError<PutResourcePermissionStatementError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<PutResourcePermissionStatementOutput, PutResourcePermissionStatementError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn source_vpc(self, input: impl Into<String>) -> Self

VPC identifier to restrict console access

pub fn set_source_vpc(self, input: Option<String>) -> Self

VPC identifier to restrict console access

pub fn get_source_vpc(&self) -> &Option<String>

VPC identifier to restrict console access

pub fn signin_source_vpce(self, input: impl Into<String>) -> Self

SignIn VPC endpoint identifier

pub fn set_signin_source_vpce(self, input: Option<String>) -> Self

SignIn VPC endpoint identifier

pub fn get_signin_source_vpce(&self) -> &Option<String>

SignIn VPC endpoint identifier

pub fn console_source_vpce(self, input: impl Into<String>) -> Self

Console VPC endpoint identifier

pub fn set_console_source_vpce(self, input: Option<String>) -> Self

Console VPC endpoint identifier

pub fn get_console_source_vpce(&self) -> &Option<String>

Console VPC endpoint identifier

pub fn vpc_source_ip(self, input: impl Into<String>) -> Self

Source IP address within VPC

pub fn set_vpc_source_ip(self, input: Option<String>) -> Self

Source IP address within VPC

pub fn get_vpc_source_ip(&self) -> &Option<String>

Source IP address within VPC

pub fn source_ip(self, input: impl Into<String>) -> Self

Source IP address

pub fn set_source_ip(self, input: Option<String>) -> Self

Source IP address

pub fn get_source_ip(&self) -> &Option<String>

Source IP address

pub fn requested_region(self, input: impl Into<String>) -> Self

AWS region where the VPC and VPC endpoint reside Required when sourceVpc or signinSourceVpce/consoleSourceVpce is provided

pub fn set_requested_region(self, input: Option<String>) -> Self

AWS region where the VPC and VPC endpoint reside Required when sourceVpc or signinSourceVpce/consoleSourceVpce is provided

pub fn get_requested_region(&self) -> &Option<String>

AWS region where the VPC and VPC endpoint reside Required when sourceVpc or signinSourceVpce/consoleSourceVpce is provided

pub fn excluded_principal(self, input: impl Into<String>) -> Self

Principal to exclude from the permission statement

pub fn set_excluded_principal(self, input: Option<String>) -> Self

Principal to exclude from the permission statement

pub fn get_excluded_principal(&self) -> &Option<String>

Principal to exclude from the permission statement

pub fn client_token(self, input: impl Into<String>) -> Self

Idempotency token for the request

pub fn set_client_token(self, input: Option<String>) -> Self

Idempotency token for the request

pub fn get_client_token(&self) -> &Option<String>

Idempotency token for the request