#[non_exhaustive]pub struct PolicyStatementBuilder { /* private fields */ }Expand description
A builder for PolicyStatement.
Implementations
Sourceimpl PolicyStatementBuilder
impl PolicyStatementBuilder
Sourcepub fn effect(self, input: impl Into<String>) -> Self
pub fn effect(self, input: impl Into<String>) -> Self
Effect of the policy statement (Allow/Deny)
Sourcepub fn set_effect(self, input: Option<String>) -> Self
pub fn set_effect(self, input: Option<String>) -> Self
Effect of the policy statement (Allow/Deny)
Sourcepub fn get_effect(&self) -> &Option<String>
pub fn get_effect(&self) -> &Option<String>
Effect of the policy statement (Allow/Deny)
Sourcepub fn principal(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn principal(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to principal.
To override the contents of this collection use set_principal.
Principal the statement applies to
Sourcepub fn set_principal(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_principal(self, input: Option<HashMap<String, String>>) -> Self
Principal the statement applies to
Sourcepub fn get_principal(&self) -> &Option<HashMap<String, String>>
pub fn get_principal(&self) -> &Option<HashMap<String, String>>
Principal the statement applies to
Sourcepub fn action(self, input: impl Into<String>) -> Self
pub fn action(self, input: impl Into<String>) -> Self
Appends an item to action.
To override the contents of this collection use set_action.
Actions the statement controls
Sourcepub fn set_action(self, input: Option<Vec<String>>) -> Self
pub fn set_action(self, input: Option<Vec<String>>) -> Self
Actions the statement controls
Sourcepub fn get_action(&self) -> &Option<Vec<String>>
pub fn get_action(&self) -> &Option<Vec<String>>
Actions the statement controls
Sourcepub fn set_resource(self, input: Option<String>) -> Self
pub fn set_resource(self, input: Option<String>) -> Self
Resource the statement applies to
Sourcepub fn get_resource(&self) -> &Option<String>
pub fn get_resource(&self) -> &Option<String>
Resource the statement applies to
Sourcepub fn condition(
self,
k: impl Into<String>,
v: HashMap<String, Vec<String>>,
) -> Self
pub fn condition( self, k: impl Into<String>, v: HashMap<String, Vec<String>>, ) -> Self
Adds a key-value pair to condition.
To override the contents of this collection use set_condition.
Condition block for the statement
Sourcepub fn set_condition(
self,
input: Option<HashMap<String, HashMap<String, Vec<String>>>>,
) -> Self
pub fn set_condition( self, input: Option<HashMap<String, HashMap<String, Vec<String>>>>, ) -> Self
Condition block for the statement
Sourcepub fn get_condition(
&self,
) -> &Option<HashMap<String, HashMap<String, Vec<String>>>>
pub fn get_condition( &self, ) -> &Option<HashMap<String, HashMap<String, Vec<String>>>>
Condition block for the statement
Sourcepub fn build(self) -> PolicyStatement
pub fn build(self) -> PolicyStatement
Consumes the builder and constructs a PolicyStatement.